(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     85221,       2001]
NotebookOptionsPosition[     47487,       1167]
NotebookOutlinePosition[     82996,       1941]
CellTagsIndexPosition[     82953,       1938]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Understanding Newton\[CloseCurlyQuote]s Method", "Title",
 CellMargins->{{76, 100}, {10, 100}}],

Cell["\<\
Piecing together Newton\[CloseCurlyQuote]s method with Mathematica \
\>", "Subsubtitle",
 CellMargins->{{73, 10}, {10, 10}}],

Cell[TextData[{
 StyleBox["Teacher: ",
  FontFamily->"Arial",
  FontWeight->"Bold"],
 "Andy Dorsett",
 StyleBox["\n",
  FontFamily->"Arial"],
 StyleBox["Class:",
  FontFamily->"Arial",
  FontWeight->"Bold"],
 StyleBox["\t",
  FontFamily->"Arial"],
 "Calculus 1"
}], "Text",
 CellChangeTimes->{{3.5092933824429502`*^9, 3.509293383490055*^9}, {
  3.5092935039511003`*^9, 3.5092935129760027`*^9}, {3.509293544065111*^9, 
  3.509293548385543*^9}}],

Cell[TextData[{
 "This tutorial will walk you through Newton\[CloseCurlyQuote]s Method for \
approximating the real zeros of a function.  This is a cumbersome task to do \
by hand, and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will enable us to see the \[OpenCurlyDoubleQuote]big-picture idea\
\[CloseCurlyDoubleQuote] of Newton\[CloseCurlyQuote]s method without the \
tedious pencil/paper or graphing calculator work that was required in the \
past."
}], "Text"],

Cell[TextData[{
 "This tutorial was developed using the interactive model ",
 ButtonBox["Learning Newton\[CloseCurlyQuote]s Method",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/LearningNewtonsMethod/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/LearningNewtonsMethod/"],
 " by Angela Sharp, Chad Pierson, and Joshua Fritz."
}], "Text"],

Cell["\<\
The premise behind Netwon\[CloseCurlyQuote]s method is that we can \
approximate a root by using slopes of lines.\
\>", "ExampleBox"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s consider a function ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " that is continuous on the interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"a", ",", "b"}], "]"}], TraditionalForm]]],
 " and differentiable on the interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", " ", "b"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  If ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "a", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "b", ")"}], TraditionalForm]]],
 " differ in sign, then, by the Intermediate Value Theorem, ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " must have at least one zero in the interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"a", ",", " ", "b"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  Let\[CloseCurlyQuote]s say, for the sake of ease, that ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is infinitely close to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", and b is infinitely close to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"6", ",", "0"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Cos", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", 
      RowBox[{"Darker", "@", "Gray"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[
    0.33333333333333337`, 0.33333333333333337`, 0.33333333333333337`], 
    Thickness[Large], LineBox[CompressedData["
1:eJw12Xk41N37B3C7GVsIM8gSKUnqydJCnTvtKtFCWVr0WJIUSj3SomylxZ5U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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{0, 2 Pi}, {-0.9999998830731719, 0.9999999999999918}}, {{
     0, 6.283185307179586}, {-0.9999998830731719, 0.9999999999999918}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, {2}]],

Cell[TextData[{
 "Now, let\[CloseCurlyQuote]s assume an initial guess of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0.5"}], TraditionalForm]]],
 ".  In other words, let\[CloseCurlyQuote]s assume that the function crosses \
the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],
  FormatType->"TraditionalForm"],
 "-axis at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0.5"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  Set the number of iterations, ",
 StyleBox["n", "Menu"],
 ", to 0.  Move the slider on the model below until the black dot is on, or \
close to, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0.5"}], TraditionalForm]]],
 ".  Once the black dot is on ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0.5"}], TraditionalForm]]],
 ", set the number of iterations, ",
 StyleBox["n", "Menu"],
 ", to 1."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f1", "[", "x_", "]"}], ":=", 
   RowBox[{"Cos", "[", "x", "]"}]}], "            ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "drop", " ", "down", " ", "menu", " ", "function", " ", "definitions"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f21", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"x", "^", "2"}], " ", "-", "2"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f3", "[", "x_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"x", "^", "3"}], " ", "-", "7"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f5", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"x", "^", "3"}], " ", "-", 
   RowBox[{"3", 
    RowBox[{"x", "^", "2"}]}], " ", "+", " ", "x", " ", "-", 
   "1"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"newton", "[", 
   RowBox[{"f_", ",", "x0_", ",", "a_", ",", "b_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"list", "=", 
      RowBox[{"NestList", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "-", 
          FractionBox[
           RowBox[{"f", "[", "#", "]"}], 
           RowBox[{
            RowBox[{"f", "'"}], "[", "#", "]"}]]}], " ", "&"}], ",", "x0", 
        ",", "n"}], "]"}]}], "}"}], ",", 
    RowBox[{"Column", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"TraditionalForm", "@", 
         RowBox[{"Text", "@", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"HoldForm", "[", 
                SubsuperscriptBox[
                 RowBox[{"{", 
                  SubscriptBox["x", "k"], "}"}], 
                 RowBox[{"k", "=", "0"}], "n"], "]"}], ",", "\"\< = \>\"", 
               ",", " ", "list"}], "}"}], "]"}], ",", "14"}], "]"}]}]}], ",", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "a", ",", "b"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"x", ",", "16"}], "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{"y", ",", "16"}], "]"}]}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "@", "Gray"}], ",", 
             RowBox[{"Thickness", "[", ".006", "]"}]}], "}"}]}], ",", 
          RowBox[{"Epilog", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Red", ",", 
               RowBox[{"Thickness", "[", ".002", "]"}], ",", 
               RowBox[{"Arrowheads", "[", ".03", "]"}], ",", 
               RowBox[{"Arrow", "[", 
                RowBox[{"Most", "[", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{
                   RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"#", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"#", ",", 
                    RowBox[{"f", "[", "#", "]"}]}], "}"}]}], "}"}], " ", 
                    "&"}], ",", "list"}], "]"}], ",", "1"}], "]"}], "]"}], 
                "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
               RowBox[{"Point", "[", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", "0"}], "}"}], "]"}]}], "}"}]}], "}"}]}], 
          ",", 
          RowBox[{"ImageSize", "\[Rule]", "360"}]}], "]"}]}], "}"}], ",", 
      "Center"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"newton", "[", 
    RowBox[{"d", ",", 
     RowBox[{"N", "[", "x0", "]"}], ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}], ",", "n"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", "f1", ",", "\"\<function\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"f1", "\[Rule]", " ", 
       RowBox[{"TraditionalForm", "[", 
        RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", " ", "PopupMenu"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "\"\<n (iterations)\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", "4", ",", 
       RowBox[{"Subscript", "[", 
        RowBox[{"\"\<x\>\"", ",", "\"\<0\>\""}], "]"}]}], "}"}], ",", "0.01", 
     ",", "6.11", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], " ", "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`d$$ = $CellContext`f1, $CellContext`n$$ = 
    0, $CellContext`x0$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`d$$], $CellContext`f1, "function"}, {$CellContext`f1 -> 
       TraditionalForm[
         Cos[$CellContext`x]]}}, {{
       Hold[$CellContext`n$$], 0, "n (iterations)"}, {0, 1}}, {{
       Hold[$CellContext`x0$$], 4, 
       Subscript["x", "0"]}, 0.01, 6.11}}, Typeset`size$$ = {
    600., {174.53125, 182.46875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`d$6449$$ = 
    False, $CellContext`n$6450$$ = False, $CellContext`x0$6451$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`d$$ = $CellContext`f1, $CellContext`n$$ = 
        0, $CellContext`x0$$ = 4}, "ControllerVariables" :> {
        Hold[$CellContext`d$$, $CellContext`d$6449$$, False], 
        Hold[$CellContext`n$$, $CellContext`n$6450$$, False], 
        Hold[$CellContext`x0$$, $CellContext`x0$6451$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`newton[$CellContext`d$$, 
        N[$CellContext`x0$$], 0, 2 Pi, $CellContext`n$$], 
      "Specifications" :> {{{$CellContext`d$$, $CellContext`f1, 
          "function"}, {$CellContext`f1 -> TraditionalForm[
            Cos[$CellContext`x]]}, ControlType -> 
         PopupMenu}, {{$CellContext`n$$, 0, "n (iterations)"}, {0, 1}, 
         ControlType -> SetterBar}, {{$CellContext`x0$$, 4, 
          Subscript["x", "0"]}, 0.01, 6.11, Appearance -> "Labeled"}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{647., {250., 257.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`newton[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := 
       Module[{$CellContext`list = 
          NestList[# - $CellContext`f[#]/Derivative[
            1][$CellContext`f][#]& , $CellContext`x0, $CellContext`n]}, 
         Column[{
           TraditionalForm[
            Text[
             Style[
              Row[{
                HoldForm[Subscript[{
                    
                    Subscript[$CellContext`x, $CellContext`k]}, \
$CellContext`k = 0]^$CellContext`n], " = ", $CellContext`list}], 14]]], 
           Plot[
            $CellContext`f[$CellContext`x], {$CellContext`x, $CellContext`a, \
$CellContext`b}, PlotRange -> All, AxesLabel -> {
              Style[$CellContext`x, 16], 
              Style[$CellContext`y, 16]}, PlotStyle -> {
              Darker[Gray], 
              Thickness[0.006]}, Epilog -> {{Red, 
               Thickness[0.002], 
               Arrowheads[0.03], 
               Arrow[
                Most[
                 Flatten[
                  Map[{{#, 0}, {#, 
                    $CellContext`f[#]}}& , $CellContext`list], 1]]]}, {
               PointSize[0.015], 
               Point[{$CellContext`x0, 0}]}}, ImageSize -> 360]}, Center]], 
       Attributes[Derivative] = {NHoldAll, ReadProtected}, 
       Attributes[Subscript] = {NHoldRest}, 
       Subscript[$CellContext`w, $CellContext`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$14`w, Notebook$$14`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$31`w, Notebook$$31`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$32`w, Notebook$$32`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$33`w, Notebook$$33`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$5`w, Notebook$$5`opt] = {2.706, 3.686}, 
       Attributes[PlotRange] = {ReadProtected}, $CellContext`f1[
         Pattern[$CellContext`x, 
          Blank[]]] := Cos[$CellContext`x]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],

Cell[TextData[{
 "Newton\[CloseCurlyQuote]s method says that if my guess, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0.5"}], TraditionalForm]]],
 ", is close enough, then the slope of the line tangent to my function at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0.5"}], TraditionalForm]]],
 ", will be close to the zero I\[CloseCurlyQuote]m trying to determine.  It \
is obvious that my guess is not close enough.  So, Newton\[CloseCurlyQuote]s \
method asks me to use this new guess (approximately ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "2.3"}], TraditionalForm]]],
 ") as my new guess.  Now, let\[CloseCurlyQuote]s add an interation.  Set the \
number of iterations, ",
 StyleBox["n", "Menu"],
 ", to 2."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"newton", "[", 
    RowBox[{"d", ",", 
     RowBox[{"N", "[", "x0", "]"}], ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}], ",", "n"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", "f1", ",", "\"\<function\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"f1", "\[Rule]", " ", 
       RowBox[{"TraditionalForm", "[", 
        RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", " ", "PopupMenu"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "\"\<n (iterations)\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", ".5", ",", 
       RowBox[{"Subscript", "[", 
        RowBox[{"\"\<x\>\"", ",", "\"\<0\>\""}], "]"}]}], "}"}], ",", "0.01", 
     ",", "6.11", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], " ", "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`d$$ = $CellContext`f1, $CellContext`n$$ = 
    2, $CellContext`x0$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`d$$], $CellContext`f1, "function"}, {$CellContext`f1 -> 
       TraditionalForm[
         Cos[$CellContext`x]]}}, {{
       Hold[$CellContext`n$$], 1, "n (iterations)"}, {0, 1, 2}}, {{
       Hold[$CellContext`x0$$], 0.5, 
       Subscript["x", "0"]}, 0.01, 6.11}}, Typeset`size$$ = {
    600., {174.53125, 182.46875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`d$1427$$ = 
    False, $CellContext`n$1428$$ = 0, $CellContext`x0$1429$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`d$$ = $CellContext`f1, $CellContext`n$$ = 
        1, $CellContext`x0$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`d$$, $CellContext`d$1427$$, False], 
        Hold[$CellContext`n$$, $CellContext`n$1428$$, 0], 
        Hold[$CellContext`x0$$, $CellContext`x0$1429$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`newton[$CellContext`d$$, 
        N[$CellContext`x0$$], 0, 2 Pi, $CellContext`n$$], 
      "Specifications" :> {{{$CellContext`d$$, $CellContext`f1, 
          "function"}, {$CellContext`f1 -> TraditionalForm[
            Cos[$CellContext`x]]}, ControlType -> 
         PopupMenu}, {{$CellContext`n$$, 1, "n (iterations)"}, {0, 1, 2}, 
         ControlType -> SetterBar}, {{$CellContext`x0$$, 0.5, 
          Subscript["x", "0"]}, 0.01, 6.11, Appearance -> "Labeled"}}, 
      "Options" :> {}, "DefaultOptions" :> {ControlPlacement -> Top}],
     ImageSizeCache->{647., {250., 257.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`newton[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := 
       Module[{$CellContext`list = 
          NestList[# - $CellContext`f[#]/Derivative[
            1][$CellContext`f][#]& , $CellContext`x0, $CellContext`n]}, 
         Column[{
           TraditionalForm[
            Text[
             Style[
              Row[{
                HoldForm[Subscript[{
                    
                    Subscript[$CellContext`x, $CellContext`k]}, \
$CellContext`k = 0]^$CellContext`n], " = ", $CellContext`list}], 14]]], 
           Plot[
            $CellContext`f[$CellContext`x], {$CellContext`x, $CellContext`a, \
$CellContext`b}, PlotRange -> All, AxesLabel -> {
              Style[$CellContext`x, 16], 
              Style[$CellContext`y, 16]}, PlotStyle -> Thickness[0.006], 
            Epilog -> {{Red, 
               Thickness[0.002], 
               Arrowheads[0.03], 
               Arrow[
                Most[
                 Flatten[
                  Map[{{#, 0}, {#, 
                    $CellContext`f[#]}}& , $CellContext`list], 1]]]}, {
               PointSize[0.015], 
               Point[{$CellContext`x0, 0}]}}, ImageSize -> {600, 325}]}, 
          Center]], Attributes[Derivative] = {NHoldAll, ReadProtected}, 
       Attributes[Subscript] = {NHoldRest}, 
       Subscript[$CellContext`w, $CellContext`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$14`w, Notebook$$14`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$31`w, Notebook$$31`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$32`w, Notebook$$32`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$33`w, Notebook$$33`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$5`w, Notebook$$5`opt] = {2.706, 3.686}, 
       Attributes[PlotRange] = {ReadProtected}, $CellContext`f1[
         Pattern[$CellContext`x, 
          Blank[]]] := Cos[$CellContext`x]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],

Cell[TextData[{
 "Newtons method got me closer to the root.  Notice the plot label on the \
graph.  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0.5"}], TraditionalForm]]],
 " was my initial guess, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "2.2304877"}], TraditionalForm]]],
 " was the result it produced as my next guess.  Using ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "2.2304877"}], TraditionalForm]]],
 " as my next guess, Newton\[CloseCurlyQuote]s method gets me closer: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "1.3806235"}], TraditionalForm]]],
 ".  "
}], "Text"],

Cell["\<\
How close should we get?  Let's make sure that 2 successive iterations are \
the same up to the hundred-thousandth.  \
\>", "Text"],

Cell[TextData[{
 "Look at the model below.  You\[CloseCurlyQuote]ll see choices for ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " = 0...6.  Click on each button until you receive the FIRST iteration that \
shows two successive estimates that are equivalent for 5 decimal places."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"newton", "[", 
    RowBox[{"d", ",", 
     RowBox[{"N", "[", "x0", "]"}], ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}], ",", "n"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", "f1", ",", "\"\<function\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"f1", "\[Rule]", " ", 
       RowBox[{"TraditionalForm", "[", 
        RowBox[{"Cos", "[", "x", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", " ", "PopupMenu"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "\"\<n (iterations)\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
      "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", ".5", ",", 
       RowBox[{"Subscript", "[", 
        RowBox[{"\"\<x\>\"", ",", "\"\<0\>\""}], "]"}]}], "}"}], ",", "0.01", 
     ",", "6.11", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], " ", "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`d$$ = $CellContext`f1, $CellContext`n$$ = 
    1, $CellContext`x0$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`d$$], $CellContext`f1, "function"}, {$CellContext`f1 -> 
       TraditionalForm[
         Cos[$CellContext`x]]}}, {{
       Hold[$CellContext`n$$], 1, "n (iterations)"}, {0, 1, 2, 3, 4, 5, 6}}, {{
       Hold[$CellContext`x0$$], 0.5, 
       Subscript["x", "0"]}, 0.01, 6.11}}, Typeset`size$$ = {
    600., {174.53125, 182.46875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`d$1505$$ = 
    False, $CellContext`n$1506$$ = 0, $CellContext`x0$1507$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`d$$ = $CellContext`f1, $CellContext`n$$ = 
        1, $CellContext`x0$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`d$$, $CellContext`d$1505$$, False], 
        Hold[$CellContext`n$$, $CellContext`n$1506$$, 0], 
        Hold[$CellContext`x0$$, $CellContext`x0$1507$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`newton[$CellContext`d$$, 
        N[$CellContext`x0$$], 0, 2 Pi, $CellContext`n$$], 
      "Specifications" :> {{{$CellContext`d$$, $CellContext`f1, 
          "function"}, {$CellContext`f1 -> TraditionalForm[
            Cos[$CellContext`x]]}, ControlType -> 
         PopupMenu}, {{$CellContext`n$$, 1, "n (iterations)"}, {0, 1, 2, 3, 4,
          5, 6}, ControlType -> SetterBar}, {{$CellContext`x0$$, 0.5, 
          Subscript["x", "0"]}, 0.01, 6.11, Appearance -> "Labeled"}}, 
      "Options" :> {}, "DefaultOptions" :> {ControlPlacement -> Top}],
     ImageSizeCache->{647., {250., 257.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`newton[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := 
       Module[{$CellContext`list = 
          NestList[# - $CellContext`f[#]/Derivative[
            1][$CellContext`f][#]& , $CellContext`x0, $CellContext`n]}, 
         Column[{
           TraditionalForm[
            Text[
             Style[
              Row[{
                HoldForm[Subscript[{
                    
                    Subscript[$CellContext`x, $CellContext`k]}, \
$CellContext`k = 0]^$CellContext`n], " = ", $CellContext`list}], 14]]], 
           Plot[
            $CellContext`f[$CellContext`x], {$CellContext`x, $CellContext`a, \
$CellContext`b}, PlotRange -> All, AxesLabel -> {
              Style[$CellContext`x, 16], 
              Style[$CellContext`y, 16]}, PlotStyle -> Thickness[0.006], 
            Epilog -> {{Red, 
               Thickness[0.002], 
               Arrowheads[0.03], 
               Arrow[
                Most[
                 Flatten[
                  Map[{{#, 0}, {#, 
                    $CellContext`f[#]}}& , $CellContext`list], 1]]]}, {
               PointSize[0.015], 
               Point[{$CellContext`x0, 0}]}}, ImageSize -> {600, 325}]}, 
          Center]], Attributes[Derivative] = {NHoldAll, ReadProtected}, 
       Attributes[Subscript] = {NHoldRest}, 
       Subscript[$CellContext`w, $CellContext`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$14`w, Notebook$$14`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$31`w, Notebook$$31`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$32`w, Notebook$$32`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$33`w, Notebook$$33`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$5`w, Notebook$$5`opt] = {2.706, 3.686}, 
       Attributes[PlotRange] = {ReadProtected}, $CellContext`f1[
         Pattern[$CellContext`x, 
          Blank[]]] := Cos[$CellContext`x]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],

Cell["\<\
While the arrows became so close that it was hard to see the red trail \
\[OpenCurlyDoubleQuote]zero-ing\[CloseCurlyDoubleQuote] in on the zero, the \
value appeared in the plot label.\
\>", "Text"],

Cell[TextData[{
 "Complete the exercises below.  Make sure to reset ",
 StyleBox["n", "Menu"],
 " so that the number 0 is selected."
}], "Text"],

Cell["\<\
Side note: If you happen to choose an initial guess that, after 6 iterations \
of Newton\[CloseCurlyQuote]s method, fails to give you an answer to the \
precision mentioned above, that means that your initial guess was too far \
off.  Start over with a new initial guess.\
\>", "ExampleBox"],

Cell[CellGroupData[{

Cell["Exercises", "Subsection"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"newton", "[", 
    RowBox[{"d", ",", 
     RowBox[{"N", "[", "x0", "]"}], ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}], ",", "n"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", "f21", ",", "\"\<function\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f21", "\[Rule]", " ", 
        RowBox[{"TraditionalForm", "[", 
         RowBox[{
          RowBox[{"x", "^", "2"}], " ", "-", "2"}], "]"}]}], ",", " ", 
       RowBox[{"f1", "\[Rule]", " ", 
        RowBox[{"TraditionalForm", "[", 
         RowBox[{"Cos", "[", "x", "]"}], "]"}]}], ",", 
       RowBox[{"f3", "\[Rule]", " ", 
        RowBox[{"TraditionalForm", "[", 
         RowBox[{
          RowBox[{"x", "^", "3"}], " ", "-", "7"}], "]"}]}], ",", 
       RowBox[{"f5", "\[Rule]", " ", 
        RowBox[{"TraditionalForm", "[", 
         RowBox[{
          RowBox[{"x", "^", "3"}], " ", "-", 
          RowBox[{"3", 
           RowBox[{"x", "^", "2"}]}], " ", "+", " ", "x", " ", "-", "1"}], 
         "]"}]}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", " ", "PopupMenu"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "\"\<n (iterations)\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
      "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", ".5", ",", 
       RowBox[{"Subscript", "[", 
        RowBox[{"\"\<x\>\"", ",", "\"\<0\>\""}], "]"}]}], "}"}], ",", "0.01", 
     ",", "6.11", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], " ", "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`d$$ = $CellContext`f21, $CellContext`n$$ = 
    1, $CellContext`x0$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`d$$], $CellContext`f21, 
       "function"}, {$CellContext`f21 -> 
       TraditionalForm[-2 + $CellContext`x^2], $CellContext`f1 -> 
       TraditionalForm[
         Cos[$CellContext`x]], $CellContext`f3 -> 
       TraditionalForm[-7 + $CellContext`x^3], $CellContext`f5 -> 
       TraditionalForm[-1 + $CellContext`x - 
         3 $CellContext`x^2 + $CellContext`x^3]}}, {{
       Hold[$CellContext`n$$], 1, "n (iterations)"}, {0, 1, 2, 3, 4, 5, 6}}, {{
       Hold[$CellContext`x0$$], 0.5, 
       Subscript["x", "0"]}, 0.01, 6.11}}, Typeset`size$$ = {
    600., {174.53125, 182.46875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`d$1574$$ = 
    False, $CellContext`n$1575$$ = 0, $CellContext`x0$1576$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`d$$ = $CellContext`f21, $CellContext`n$$ = 
        1, $CellContext`x0$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`d$$, $CellContext`d$1574$$, False], 
        Hold[$CellContext`n$$, $CellContext`n$1575$$, 0], 
        Hold[$CellContext`x0$$, $CellContext`x0$1576$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`newton[$CellContext`d$$, 
        N[$CellContext`x0$$], 0, 2 Pi, $CellContext`n$$], 
      "Specifications" :> {{{$CellContext`d$$, $CellContext`f21, 
          "function"}, {$CellContext`f21 -> 
          TraditionalForm[-2 + $CellContext`x^2], $CellContext`f1 -> 
          TraditionalForm[
            Cos[$CellContext`x]], $CellContext`f3 -> 
          TraditionalForm[-7 + $CellContext`x^3], $CellContext`f5 -> 
          TraditionalForm[-1 + $CellContext`x - 
            3 $CellContext`x^2 + $CellContext`x^3]}, ControlType -> 
         PopupMenu}, {{$CellContext`n$$, 1, "n (iterations)"}, {0, 1, 2, 3, 4,
          5, 6}, ControlType -> SetterBar}, {{$CellContext`x0$$, 0.5, 
          Subscript["x", "0"]}, 0.01, 6.11, Appearance -> "Labeled"}}, 
      "Options" :> {}, "DefaultOptions" :> {ControlPlacement -> Top}],
     ImageSizeCache->{647., {252., 259.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`newton[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := 
       Module[{$CellContext`list = 
          NestList[# - $CellContext`f[#]/Derivative[
            1][$CellContext`f][#]& , $CellContext`x0, $CellContext`n]}, 
         Column[{
           TraditionalForm[
            Text[
             Style[
              Row[{
                HoldForm[Subscript[{
                    
                    Subscript[$CellContext`x, $CellContext`k]}, \
$CellContext`k = 0]^$CellContext`n], " = ", $CellContext`list}], 14]]], 
           Plot[
            $CellContext`f[$CellContext`x], {$CellContext`x, $CellContext`a, \
$CellContext`b}, PlotRange -> All, AxesLabel -> {
              Style[$CellContext`x, 16], 
              Style[$CellContext`y, 16]}, PlotStyle -> Thickness[0.006], 
            Epilog -> {{Red, 
               Thickness[0.002], 
               Arrowheads[0.03], 
               Arrow[
                Most[
                 Flatten[
                  Map[{{#, 0}, {#, 
                    $CellContext`f[#]}}& , $CellContext`list], 1]]]}, {
               PointSize[0.015], 
               Point[{$CellContext`x0, 0}]}}, ImageSize -> {600, 325}]}, 
          Center]], Attributes[Derivative] = {NHoldAll, ReadProtected}, 
       Attributes[Subscript] = {NHoldRest}, 
       Subscript[$CellContext`w, $CellContext`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$14`w, Notebook$$14`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$31`w, Notebook$$31`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$32`w, Notebook$$32`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$33`w, Notebook$$33`opt] = {2.706, 3.686}, 
       Subscript[Notebook$$5`w, Notebook$$5`opt] = {2.706, 3.686}, 
       Attributes[PlotRange] = {ReadProtected}, $CellContext`f21[
         Pattern[$CellContext`x, 
          Blank[]]] := $CellContext`x^2 - 2, $CellContext`f1[
         Pattern[$CellContext`x, 
          Blank[]]] := Cos[$CellContext`x], $CellContext`f3[
         Pattern[$CellContext`x, 
          Blank[]]] := $CellContext`x^3 - 7, $CellContext`f5[
         Pattern[$CellContext`x, 
          Blank[]]] := $CellContext`x^3 - 3 $CellContext`x^2 + $CellContext`x - 
        1}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}],
   Deployed->True],
  Manipulate`InterpretManipulate[1]]], "Input"],

Cell[TextData[{
 "Select ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{
     SuperscriptBox["x", "2"], "-", "2"}]}], TraditionalForm]]],
 " from the drop-down menu in the interactive demonstration above.  Use an \
initial guess of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "6"}], TraditionalForm]]],
 ".  How many iterations does it take until successive guesses are equivalent \
to 5 decimal places?  Give the approximated zero."
}], "Text"],

Cell["How many iterations did it take?", "Question"],

Cell["", "Answer"],

Cell["What is the approximated root?", "Question"],

Cell["", "Answer"],

Cell["", "Spacer"],

Cell[TextData[{
 "Now, select  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{
     SuperscriptBox["x", "3"], "-", "7"}]}], TraditionalForm]]],
 " from the drop-down menu.  Reset the value of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " (iterations) to the number 0.  Use an initial guess of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "5"}], TraditionalForm]]],
 ".  How many iterations does it take until successive guesses are equivalent \
to 5 decimal places?  Give the approximated zero."
}], "Text"],

Cell["How many iterations did it take?", "Question"],

Cell["", "Answer"],

Cell["What is the approximated root?", "Question"],

Cell["", "Answer"],

Cell["", "Spacer"],

Cell["\<\
Look at the final cubic equation from the drop-down menu in the model.  Use \
any initial guess you would like.  Find an approximation for the zero such \
that 2 successive iterations are equivalent to 5 decimal places.\
\>", "Text"],

Cell["What was your initial guess?", "Question"],

Cell["", "Answer"],

Cell["What is the approximated root?", "Question"],

Cell["", "Answer"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1125, 834},
WindowMargins->{{136, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefinitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "Presentation"], 
             CellMargins -> {{100, 100}, {10, 150}}, FontSize -> 54], 
            Cell[
             StyleData["LargeChapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{84, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontWeight -> "Plain", FontColor -> 
             RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             WholeCellGroupOpener -> True, 
             CellMargins -> {{88, 60}, {20, 12}}, FontWeight -> "Plain"]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             StripStyleOnPaste -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               Inherited 1.75, Inherited 1.75}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"]], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontFamily -> "Helvetica", 
             FontSize -> 17]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Editorial"], ShowCellBracket -> Automatic, 
             CellMargins -> {{24, 10}, {6, 6}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[0.786999, 0.0386053, 0.0571756]}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Edit:"}], FontFamily -> "Helvetica", FontSize -> 
                 16, FontWeight -> "Bold", CellBaseline -> Baseline], None}, {
               None, None}}, DefaultNewInlineCellStyle -> "None", Hyphenation -> 
             True, LineSpacing -> {1, 3}, LanguageCategory -> 
             "NaturalLanguage", FontFamily -> "Helvetica", FontSize -> 19, 
             FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Editorial", "SlideShow"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          StyleData["DialogStyle"], FontSize -> 17], 
         Cell[
          StyleData["TooltipLabel"], CellFrame -> 1., CellFrameMargins :> 
          CurrentValue["TooltipFrameMargins"], CellFrameColor :> 
          CurrentValue[{"SystemColor", "TooltipFrame"}], TextAlignment -> 
          Left, TextJustification -> 0., ShowStringCharacters -> False, 
          FontFamily :> CurrentValue["TooltipFontFamily"], FontSize :> 
          CurrentValue["TooltipFontSize"], FontWeight -> "Plain", FontSlant -> 
          "Plain", Magnification -> 1.5, FontColor :> 
          CurrentValue[{"SystemColor", "TooltipText"}], FontOpacity -> 1., 
          Background :> CurrentValue[{"SystemColor", "Tooltip"}]], 
         Cell[
          StyleData["Question"], CellFrame -> {{0.25, 0.25}, {0.25, 0.25}}, 
          CellMargins -> {{145, 24}, {0, 10}}, CellFrameColor -> 
          GrayLevel[0.65], FontFamily -> "Georgia", FontSize -> 18, 
          Background -> RGBColor[0.95, 0.95, 0.95]], 
         Cell[
          StyleData["Answer"], CellFrame -> {{0.25, 0.25}, {0.25, 0}}, 
          CellMargins -> {{72, 24}, {10, 0}}, CellFrameColor -> 
          GrayLevel[0.65], CellFrameLabels -> {{
             Cell[
              TextData["Answer:"], "LabelStyleShort"], None}, {None, None}}, 
          FontFamily -> "Georgia", FontSize -> 18, Background -> 
          RGBColor[0.9999, 0.9999, 0.9999]], 
         Cell[
          StyleData["ExampleBox"], CellFrame -> 0.5, 
          CellMargins -> {{228, 243}, {10, 10}}, TextAlignment -> Center, 
          FontFamily -> "Times", FontSize -> 18, Background -> 
          RGBColor[0.94, 0.91, 0.88]]}, Open]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> 
  "8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, 2011)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 101, 1, 172, "Title"],
Cell[671, 25, 134, 3, 50, "Subsubtitle"],
Cell[808, 30, 443, 16, 75, "Text"],
Cell[1254, 48, 476, 10, 104, "Text"],
Cell[1733, 60, 390, 8, 75, "Text"],
Cell[2126, 70, 143, 3, 74, "ExampleBox"],
Cell[2272, 75, 1468, 51, 108, "Text"],
Cell[CellGroupData[{
Cell[3765, 130, 333, 10, 31, "Input"],
Cell[4101, 142, 8628, 148, 235, "Output"]
}, {2}]],
Cell[12741, 293, 865, 29, 106, "Text"],
Cell[CellGroupData[{
Cell[13631, 326, 5248, 140, 481, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[18882, 468, 4646, 98, 528, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[23540, 569, 745, 19, 134, "Text"],
Cell[CellGroupData[{
Cell[24310, 592, 1328, 34, 102, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[25641, 628, 4652, 97, 528, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[30305, 728, 602, 19, 104, "Text"],
Cell[30910, 749, 141, 3, 75, "Text"],
Cell[31054, 754, 301, 6, 76, "Text"],
Cell[CellGroupData[{
Cell[31380, 764, 1382, 36, 113, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[32765, 802, 4676, 97, 528, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[37453, 902, 208, 4, 76, "Text"],
Cell[37664, 908, 144, 4, 47, "Text"],
Cell[37811, 914, 301, 5, 112, "ExampleBox"],
Cell[CellGroupData[{
Cell[38137, 923, 31, 0, 60, "Subsection"],
Cell[38171, 925, 2004, 52, 176, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[40178, 979, 5455, 112, 532, InheritFromParent],
Cell[45636, 1093, 497, 15, 105, "Text"],
Cell[46136, 1110, 52, 0, 47, "Question"],
Cell[46191, 1112, 18, 0, 47, "Answer"],
Cell[46212, 1114, 50, 0, 47, "Question"],
Cell[46265, 1116, 18, 0, 47, "Answer"],
Cell[46286, 1118, 18, 0, 20, "Spacer"],
Cell[46307, 1120, 568, 17, 105, "Text"],
Cell[46878, 1139, 52, 0, 47, "Question"],
Cell[46933, 1141, 18, 0, 47, "Answer"],
Cell[46954, 1143, 50, 0, 47, "Question"],
Cell[47007, 1145, 18, 0, 47, "Answer"],
Cell[47028, 1147, 18, 0, 20, "Spacer"],
Cell[47049, 1149, 243, 4, 75, "Text"],
Cell[47295, 1155, 48, 0, 47, "Question"],
Cell[47346, 1157, 18, 0, 47, "Answer"],
Cell[47367, 1159, 50, 0, 47, "Question"],
Cell[47420, 1161, 18, 0, 47, "Answer"],
Cell[47441, 1163, 18, 0, 20, "Spacer"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
